==> owncloud-app-calendar-1%3A1.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/calendar/l10n/is.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Dagatal",
    "New event" : "Nýr atburður",
    "Global" : "Almennt",
    "None" : "Ekkert",
    "Attendees" : "Þáttakendur",
    "Reminders" : "Áminningar",
    "Does not repeat" : "Endurtekst ekki",
    "Daily" : "Daglega",
    "Weekly" : "Vikulega",
    "Every Weekday" : "Alla vikudaga",
    "Bi-weekly" : "Hálfsmánaðarlega",
    "Monthly" : "Mánaðarlega",
    "Yearly" : "Árlega",
    "never" : "aldrei",
    "by occurances" : "eftir tilvikum",
    "by date" : "eftir dagsetningu",
    "by monthday" : "eftir mánaðardegi",
    "by weekday" : "eftir vikudegi",
    "by events date" : "eftir dagsetningu atburðar",
    "by yearday(s)" : "eftir degi ársins",
    "by week no(s)" : "eftir vikunúmerum",
    "by day and month" : "eftir degi og mánuði",
    "Monday" : "Mánudagur",
    "Tuesday" : "Þriðjudagur",
    "Wednesday" : "Miðvikudagur",
    "Thursday" : "Fimmtudagur",
    "Friday" : "Föstudagur",
    "Saturday" : "Laugardagur",
    "Sunday" : "Sunnudagur",
    "Other" : "Annað",
    "Individual" : "Einstaklingur",
    "Group" : "Hópur",
    "Resource" : "Tilfang",
    "Room" : "Herbergi",
    "Unknown" : "Óþekkt",
    "Required" : "þetta þarf",
    "Optional" : "Valkvætt",
    "Does not attend" : "Mætir ekki",
    "When shared show full event" : "Þegar er deilt, birta allan atburð",
    "When shared show only busy" : "Þegar er deilt, birta eingöngu upptekið",
    "When shared hide this event" : "Þegar er deilt, fela þennan atburð",
    "At time of event" : "Þegar atburður á sér stað",
    "5 minutes before" : "5 mínútum fyrir",
    "10 minutes before" : "10 mínútum fyrir",
    "15 minutes before" : "15 mínútum fyrir",
    "30 minutes before" : "30 mínútum fyrir",
    "1 hour before" : "1 klukkustund fyrir ",
    "2 hours before" : "2 klukkustundum fyrir",
    "Custom" : "Sérsniðið",
    "Audio" : "Hljóð",
    "E Mail" : "Tölvupóstur",
    "Pop up" : "Sprettgluggi",
    "sec" : "sek",
    "min" : "mín",
    "hours" : "klukkustundir",
    "days" : "daga",
    "week" : "vika",
    "Before" : "Fyrir",
    "After" : "Eftir",
    "Start" : "Upphaf",
    "End" : "Endir",
    "Week {number} of {year}" : "Vika {number},{year}",
    "Successfully imported" : "Innflutningur tókst",
    "Partially imported, 1 failure" : "Flutt inn að hluta, 1 villa",
    "Partially imported, {n} failures" : "Flutt inn að hluta, {n} villur",
    "Audio alarm" : "Hljóðáminning",
    "Pop-up" : "Sprettgluggi",
    "E-Mail" : "Tölvupóstfang",
    "{type} {time} before the event starts" : "{type} {time} áður en atburður hefst",
    "{type} {time} before the event ends" : "{type} {time} áður en atburður endar",
    "{type} {time} after the event starts" : "{type} {time} eftir að atburður hefst",
    "{type} {time} after the event ends" : "{type} {time} eftir að atburður endar",
    "{type} at the event's start" : "{type} við upphafstíma atburðar",
    "{type} at the event's end" : "{type} við endatíma atburðar",
    "{type} at {time}" : "{type} klukkan {time}",
    "{calendar} shared by {owner}" : "{calendar} deilt af {owner}",
    "Day" : "Dagur",
    "Week" : "Vika",
    "Month" : "Mánuður",
    "Today" : "Í dag",
    "Share Calendar" : "Deila dagatali",
    "group" : "hópur",
    "New Calendar" : "Nýtt dagatal",
    "Create" : "Búa til",
    "Subscriptions" : "Áskriftir",
    "New Subscription" : "Ný áskrift",
    "Url" : "Slóð",
    "Edit event" : "Breyta atburði",
    "Delete Event" : "Eyða atburði",
    "Save Event" : "Vista atburð",
    "Time" : "Tími",
    "Type" : "Tegund",
    "Relative" : "Hlutfallslegt",
    "Absolute" : "Algilt",
    "Date" : "Dagsetning",
    "Repeat" : "Endurtaka",
    "times every" : "sinnum hverjar",
    "Add" : "Bæta við",
    "Please add your email address in the personal settings in order to add attendees." : "Settu inn tölvupóstfangið þitt í einkastillingum þínum svo að þú getir bætt við þátttakendum.",
    "Title of the Event" : "Titill atburðar",
    "from" : "frá",
    "to" : "til",
    "All day Event" : "Heilsdagsviðburður",
    "Location" : "Staðsetning",
    "starts" : "byrjar",
    "ends" : "endar",
    "Delete" : "Eyða",
    "Cancel" : "Hætta við",
    "More ..." : "Meira...",
    "Update" : "Uppfæra",
    "Close" : "Loka",
    "Interval" : "Millibil",
    "Description" : "Lýsing",
    "Export" : "Flytja út",
    "Import Calendars" : "Flytja inn dagatöl",
    "Import canceled" : "Hætt við innflutning",
    "Analyzing calendar" : "Greini dagatal",
    "The file contains objects incompatible with the selected calendar" : "Skráin inniheldur atriði sem ekki eru samhæfanleg völdu dagatali",
    "New calendar" : "Nýtt dagatal",
    "Import scheduled" : "Áætlaður innflutningur",
    "Settings" : "Stillingar",
    "Import calendar" : "Flytja inn dagatal",
    "No Calendars selected for import" : "Engin dagatöl valin til innflutnings",
    "Primary CalDAV address" : "Aðal-CalDAV-vistfang",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV-vistfang"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");

==> owncloud-app-calendar-1%3A1.3.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/calendar/l10n/is.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Dagatal",
    "Individual" : "Einstaklingur",
    "Group" : "Hópur",
    "Resource" : "Tilfang",
    "Room" : "Herbergi",
    "Unknown" : "Óþekkt",
    "Required" : "þetta þarf",
    "Optional" : "Valkvætt",
    "Does not attend" : "Mætir ekki",
    "New event" : "Nýr atburður",
    "Attendees" : "Þáttakendur",
    "Reminders" : "Áminningar",
    "Repeating" : "Endurtekning",
    "When shared show full event" : "Þegar er deilt, birta allan atburð",
    "When shared show only busy" : "Þegar er deilt, birta eingöngu upptekið",
    "When shared hide this event" : "Þegar er deilt, fela þennan atburð",
    "Please add a title!" : "Settu inn titil!",
    "Please select a calendar!" : "Veldu dagatal!",
    "Global" : "Almennt",
    "None" : "Ekkert",
    "Every day" : "Daglega",
    "Every week" : "Vikulega",
    "Every month" : "Mánuður",
    "Every year" : "Árlega",
    "never" : "aldrei",
    "after" : "eftir",
    "At time of event" : "Þegar atburður á sér stað",
    "5 minutes before" : "5 mínútum fyrir",
    "10 minutes before" : "10 mínútum fyrir",
    "15 minutes before" : "15 mínútum fyrir",
    "30 minutes before" : "30 mínútum fyrir",
    "1 hour before" : "1 klukkustund fyrir ",
    "2 hours before" : "2 klukkustundum fyrir",
    "Custom" : "Sérsniðið",
    "Audio" : "Hljóð",
    "E Mail" : "Tölvupóstur",
    "Pop up" : "Sprettgluggi",
    "sec" : "sek",
    "min" : "mín",
    "hours" : "klukkustundir",
    "days" : "daga",
    "week" : "vika",
    "before" : "fyrir",
    "start" : "upphaf",
    "end" : "endir",
    "Editing reminders of uknown type not supported." : "Breytingar á áminningum með óþekktu sniði er ekki stutt.",
    "Week {number} of {year}" : "Vika {number},{year}",
    "Successfully imported" : "Innflutningur tókst",
    "Partially imported, 1 failure" : "Flutt inn að hluta, 1 villa",
    "Partially imported, {n} failures" : "Flutt inn að hluta, {n} villur",
    "Audio alarm" : "Hljóðáminning",
    "Pop-up" : "Sprettgluggi",
    "E-Mail" : "Tölvupóstfang",
    "{type} {time} before the event starts" : "{type} {time} áður en atburður hefst",
    "{type} {time} before the event ends" : "{type} {time} áður en atburður endar",
    "{type} {time} after the event starts" : "{type} {time} eftir að atburður hefst",
    "{type} {time} after the event ends" : "{type} {time} eftir að atburður endar",
    "{type} at the event's start" : "{type} við upphafstíma atburðar",
    "{type} at the event's end" : "{type} við endatíma atburðar",
    "{type} at {time}" : "{type} klukkan {time}",
    "{calendar} shared by {owner}" : "{calendar} deilt af {owner}",
    "Title of the Event" : "Titill atburðar",
    "starts" : "byrjar",
    "ends" : "endar",
    "All day Event" : "Heilsdagsviðburður",
    "Location" : "Staðsetning",
    "Delete" : "Eyða",
    "Cancel" : "Hætta við",
    "More ..." : "Meira...",
    "Create" : "Búa til",
    "Update" : "Uppfæra",
    "Close" : "Loka",
    "Description" : "Lýsing",
    "Export" : "Flytja út",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Vegna villu í frumkóða, verður dagatalið ekki nothæft með stuðningi við pípaða vinnslu tilfanga.",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Hafðu samband við kerfisstjóra og biddu þá/hann um að gera \"asset-pipeline.enabled\" stillingakostinn óvirkann.",
    "Day" : "Dagur",
    "Week" : "Vika",
    "Month" : "Mánuður",
    "Today" : "Í dag",
    "Share Calendar" : "Deila dagatali",
    "More" : "Meira",
    "Edit" : "Breyta",
    "group" : "hópur",
    "New Calendar" : "Nýtt dagatal",
    "Subscriptions" : "Áskriftir",
    "New Subscription" : "Ný áskrift",
    "Url" : "Slóð",
    "Edit event" : "Breyta atburði",
    "Delete Event" : "Eyða atburði",
    "Save Event" : "Vista atburð",
    "Time" : "Tími",
    "Type" : "Tegund",
    "Relative" : "Hlutfallslegt",
    "Absolute" : "Algilt",
    "Repeat" : "Endurtaka",
    "times every" : "sinnum hverjar",
    "Add" : "Bæta við",
    "E-Mail address of attendee" : "Tölvupóstfang þátttakanda",
    "Please add your email address in the personal settings in order to add attendees." : "Settu inn tölvupóstfangið þitt í einkastillingum þínum svo að þú getir bætt við þátttakendum.",
    "from" : "frá",
    "to" : "til",
    "This event's repeating rule is not supported yet." : "Endurtekningarregla þessa atburðar er ekki ennþá studd.",
    "Support for advanced rules will be added with subsequent updates." : "Stuðningi við flóknari reglur verður bætt við í væntanlegum uppfærslum.",
    "Reset repeating rule" : "Endursetja endurtekningarreglu",
    "Repeat every ..." : "Endurtaka ...",
    "end repeat ..." : "enda endurtekningu ...",
    "times" : "sinnum",
    "Import Calendars" : "Flytja inn dagatöl",
    "Import canceled" : "Hætt við innflutning",
    "Analyzing calendar" : "Greini dagatal",
    "The file contains objects incompatible with the selected calendar" : "Skráin inniheldur atriði sem ekki eru samhæfanleg völdu dagatali",
    "New calendar" : "Nýtt dagatal",
    "Import scheduled" : "Áætlaður innflutningur",
    "Settings" : "Stillingar",
    "Import calendar" : "Flytja inn dagatal",
    "No Calendars selected for import" : "Engin dagatöl valin til innflutnings",
    "Primary CalDAV address" : "Aðal-CalDAV-vistfang",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV-vistfang"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
